# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.token_standard import TokenStandard  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestTokenStandard(unittest.TestCase):
    """TokenStandard unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTokenStandard(self):
        """Test TokenStandard"""
        # inst = TokenStandard()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.notification_signature_public_key_data import NotificationSignaturePublicKeyData  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestNotificationSignaturePublicKeyData(unittest.TestCase):
    """NotificationSignaturePublicKeyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NotificationSignaturePublicKeyData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationSignaturePublicKeyData`
        """
        model = circle.web3.configurations.models.notification_signature_public_key_data.NotificationSignaturePublicKeyData()  # noqa: E501
        if include_optional :
            return NotificationSignaturePublicKeyData(
                id = '09379bc1-4871-45ad-8b8b-8027795df70d', 
                algorithm = 'ECDSA_SHA_256', 
                public_key = 'QFkwewylAoZIzj0CBQYIKoZIzj0DAQcDQgAEEext6d7AimvYFDAKBwsUsGXrhqmRHNPYum7V/BwfvJLmJeSMe2V0b9eWKPuFxAEH8HCY/MSZdBI+q/E6IdPnSg==', 
                create_date = '2023-06-01T18:18:06.931526Z'
            )
        else :
            return NotificationSignaturePublicKeyData(
                id = '09379bc1-4871-45ad-8b8b-8027795df70d',
                algorithm = 'ECDSA_SHA_256',
                public_key = 'QFkwewylAoZIzj0CBQYIKoZIzj0DAQcDQgAEEext6d7AimvYFDAKBwsUsGXrhqmRHNPYum7V/BwfvJLmJeSMe2V0b9eWKPuFxAEH8HCY/MSZdBI+q/E6IdPnSg==',
                create_date = '2023-06-01T18:18:06.931526Z',
        )
        """

    def testNotificationSignaturePublicKeyData(self):
        """Test NotificationSignaturePublicKeyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.faucet_request import FaucetRequest  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestFaucetRequest(unittest.TestCase):
    """FaucetRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FaucetRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FaucetRequest`
        """
        model = circle.web3.configurations.models.faucet_request.FaucetRequest()  # noqa: E501
        if include_optional :
            return FaucetRequest(
                address = '', 
                blockchain = 'MATIC-AMOY', 
                native = True, 
                usdc = True, 
                eurc = True
            )
        else :
            return FaucetRequest(
                address = '',
                blockchain = 'MATIC-AMOY',
        )
        """

    def testFaucetRequest(self):
        """Test FaucetRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.entity_config import EntityConfig  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestEntityConfig(unittest.TestCase):
    """EntityConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EntityConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EntityConfig`
        """
        model = circle.web3.configurations.models.entity_config.EntityConfig()  # noqa: E501
        if include_optional :
            return EntityConfig(
                data = circle.web3.configurations.models.entity_config_data.EntityConfig_data(
                    app_id = '78fb905b-12c2-45aa-8fc4-c60261c9e9ee', )
            )
        else :
            return EntityConfig(
        )
        """

    def testEntityConfig(self):
        """Test EntityConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.webhook_subscriptions_api import WebhookSubscriptionsApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestWebhookSubscriptionsApi(unittest.TestCase):
    """WebhookSubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.webhook_subscriptions_api.WebhookSubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Create a notification subscription  # noqa: E501
        """
        pass

    def test_delete_subscription(self):
        """Test case for delete_subscription

        Delete a notification subscription  # noqa: E501
        """
        pass

    def test_get_notification_signature(self):
        """Test case for get_notification_signature

        Get a notification signature public key  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Retrieve a notification subscription  # noqa: E501
        """
        pass

    def test_get_subscriptions(self):
        """Test case for get_subscriptions

        Get all notification subscriptions  # noqa: E501
        """
        pass

    def test_update_subscription(self):
        """Test case for update_subscription

        Update a notification subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.not_found_response import NotFoundResponse  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestNotFoundResponse(unittest.TestCase):
    """NotFoundResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NotFoundResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotFoundResponse`
        """
        model = circle.web3.configurations.models.not_found_response.NotFoundResponse()  # noqa: E501
        if include_optional :
            return NotFoundResponse(
                code = 56, 
                message = ''
            )
        else :
            return NotFoundResponse(
                code = 56,
                message = '',
        )
        """

    def testNotFoundResponse(self):
        """Test NotFoundResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from circle.web3.configurations.models.blockchain import Blockchain
from circle.web3.configurations.models.token_standard import TokenStandard

class Token(BaseModel):
    """
    Token
    """
    id: StrictStr = Field(..., description="System-generated unique identifier of the resource.")
    name: Optional[StrictStr] = Field(None, description="Blockchain name of the specified token.")
    standard: Optional[TokenStandard] = None
    blockchain: Blockchain = Field(...)
    decimals: Optional[StrictInt] = Field(None, description="Number of decimal places shown in the token amount.")
    is_native: StrictBool = Field(..., alias="isNative", description="Defines if the token is a native token of the specified blockchain. If TRUE, the token is a native token.")
    symbol: Optional[StrictStr] = Field(None, description="Blockchain symbol of the specified token.")
    token_address: Optional[StrictStr] = Field(None, alias="tokenAddress", description="Blockchain address of the specified token.")
    update_date: datetime = Field(..., alias="updateDate", description="Date and time the resource was last updated, in ISO-8601 UTC format.")
    create_date: datetime = Field(..., alias="createDate", description="Date and time the resource was created, in ISO-8601 UTC format.")
    __properties = ["id", "name", "standard", "blockchain", "decimals", "isNative", "symbol", "tokenAddress", "updateDate", "createDate"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Token:
        """Create an instance of Token from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Token:
        """Create an instance of Token from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Token.parse_obj(obj)

        _obj = Token.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "standard": obj.get("standard"),
            "blockchain": obj.get("blockchain"),
            "decimals": obj.get("decimals"),
            "is_native": obj.get("isNative"),
            "symbol": obj.get("symbol"),
            "token_address": obj.get("tokenAddress"),
            "update_date": obj.get("updateDate"),
            "create_date": obj.get("createDate")
        })
        return _obj





# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.faucet_api import FaucetApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestFaucetApi(unittest.TestCase):
    """FaucetApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.faucet_api.FaucetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_request_testnet_tokens(self):
        """Test case for request_testnet_tokens

        Request testnet tokens  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from circle.web3.configurations.models.testnet_blockchain import TestnetBlockchain

class FaucetRequest(BaseModel):
    """
    FaucetRequest
    """
    address: StrictStr = Field(..., description="The blockchain address generated upon wallet creation.")
    blockchain: TestnetBlockchain = Field(...)
    native: Optional[StrictBool] = Field(False, description="Request native testnet tokens.")
    usdc: Optional[StrictBool] = Field(False, description="Request USDC testnet tokens.")
    eurc: Optional[StrictBool] = Field(False, description="Request EURC testnet tokens.")
    __properties = ["address", "blockchain", "native", "usdc", "eurc"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FaucetRequest:
        """Create an instance of FaucetRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FaucetRequest:
        """Create an instance of FaucetRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FaucetRequest.parse_obj(obj)

        _obj = FaucetRequest.parse_obj({
            "address": obj.get("address"),
            "blockchain": obj.get("blockchain"),
            "native": obj.get("native") if obj.get("native") is not None else False,
            "usdc": obj.get("usdc") if obj.get("usdc") is not None else False,
            "eurc": obj.get("eurc") if obj.get("eurc") is not None else False
        })
        return _obj





# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.monitor_tokens_api import MonitorTokensApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestMonitorTokensApi(unittest.TestCase):
    """MonitorTokensApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.monitor_tokens_api.MonitorTokensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_monitored_tokens(self):
        """Test case for create_monitored_tokens

        Set monitored tokens  # noqa: E501
        """
        pass

    def test_delete_monitored_tokens(self):
        """Test case for delete_monitored_tokens

        Delete monitored tokens  # noqa: E501
        """
        pass

    def test_list_monitored_tokens(self):
        """Test case for list_monitored_tokens

        Retrieve existing monitored tokens.  # noqa: E501
        """
        pass

    def test_update_monitored_tokens(self):
        """Test case for update_monitored_tokens

        Update monitored tokens  # noqa: E501
        """
        pass

    def test_update_monitored_tokens_scope(self):
        """Test case for update_monitored_tokens_scope

        Update monitored tokens scope  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.token import Token  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestToken(unittest.TestCase):
    """Token unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Token
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Token`
        """
        model = circle.web3.configurations.models.token.Token()  # noqa: E501
        if include_optional :
            return Token(
                id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5', 
                name = '', 
                standard = 'ERC20', 
                blockchain = 'MATIC-AMOY', 
                decimals = 56, 
                is_native = True, 
                symbol = '', 
                token_address = '', 
                update_date = '2023-01-01T12:04:05Z', 
                create_date = '2023-01-01T12:04:05Z'
            )
        else :
            return Token(
                id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5',
                blockchain = 'MATIC-AMOY',
                is_native = True,
                update_date = '2023-01-01T12:04:05Z',
                create_date = '2023-01-01T12:04:05Z',
        )
        """

    def testToken(self):
        """Test Token"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictBool, StrictStr

class Subscription(BaseModel):
    """
    Contains information about a webhook notification subscription.
    """
    id: StrictStr = Field(..., description="System-generated unique identifier of the resource.")
    name: StrictStr = Field(..., description="Name of the webhook notification subscription.")
    endpoint: StrictStr = Field(..., description="URL of the endpoint subscribing to notifications. Must be enabled to receive notifications.")
    enabled: StrictBool = Field(..., description="Whether the subscription is enabled. `true` indicates the subscription is enabled.")
    create_date: datetime = Field(..., alias="createDate", description="Date and time the resource was created, in ISO-8601 UTC format.")
    update_date: datetime = Field(..., alias="updateDate", description="Date and time the resource was last updated, in ISO-8601 UTC format.")
    __properties = ["id", "name", "endpoint", "enabled", "createDate", "updateDate"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Subscription:
        """Create an instance of Subscription from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Subscription:
        """Create an instance of Subscription from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Subscription.parse_obj(obj)

        _obj = Subscription.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "endpoint": obj.get("endpoint"),
            "enabled": obj.get("enabled"),
            "create_date": obj.get("createDate"),
            "update_date": obj.get("updateDate")
        })
        return _obj





# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.subscription import Subscription  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestSubscription(unittest.TestCase):
    """Subscription unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Subscription
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Subscription`
        """
        model = circle.web3.configurations.models.subscription.Subscription()  # noqa: E501
        if include_optional :
            return Subscription(
                id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5', 
                name = 'Transactions Webhook', 
                endpoint = 'https://example.org/handler/for/notifications', 
                enabled = True, 
                create_date = '2023-01-01T12:04:05Z', 
                update_date = '2023-01-01T12:04:05Z'
            )
        else :
            return Subscription(
                id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5',
                name = 'Transactions Webhook',
                endpoint = 'https://example.org/handler/for/notifications',
                enabled = True,
                create_date = '2023-01-01T12:04:05Z',
                update_date = '2023-01-01T12:04:05Z',
        )
        """

    def testSubscription(self):
        """Test Subscription"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.health_api import HealthApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestHealthApi(unittest.TestCase):
    """HealthApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.health_api.HealthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_ping(self):
        """Test case for ping

        Ping  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.subscriptions import Subscriptions  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestSubscriptions(unittest.TestCase):
    """Subscriptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Subscriptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Subscriptions`
        """
        model = circle.web3.configurations.models.subscriptions.Subscriptions()  # noqa: E501
        if include_optional :
            return Subscriptions(
                data = [
                    circle.web3.configurations.models.subscription.Subscription(
                        id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5', 
                        name = 'Transactions Webhook', 
                        endpoint = 'https://example.org/handler/for/notifications', 
                        enabled = True, 
                        create_date = '2023-01-01T12:04:05Z', 
                        update_date = '2023-01-01T12:04:05Z', )
                    ]
            )
        else :
            return Subscriptions(
        )
        """

    def testSubscriptions(self):
        """Test Subscriptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
